import { I as IntTypes, F as FloatTypes, g as getDefaultExportFromCjs, a as axios, r as runPipelineEmscripten, b as InterfaceTypes, i as imageTransferables, c as IOTypes, m as meshTransferables, d as getTransferables, e as getFileExtension } from './runPipelineEmscripten-fbbec809.js';

const version$1 = '1.0.0-b.149';
var version$2 = version$1;

const itkConfig = {
    pipelineWorkerUrl: `https://cdn.jsdelivr.net/npm/itk-wasm@${version$2}/dist/web-workers/min-bundles/pipeline.worker.js`,
    imageIOUrl: `https://cdn.jsdelivr.net/npm/itk-image-io@${version$2}`,
    meshIOUrl: `https://cdn.jsdelivr.net/npm/itk-mesh-io@${version$2}`,
    pipelinesUrl: `https://cdn.jsdelivr.net/npm/itk-wasm@${version$2}/dist/pipelines`
};
var config = itkConfig;

const PixelTypes = {
    Unknown: 'Unknown',
    Scalar: 'Scalar',
    RGB: 'RGB',
    RGBA: 'RGBA',
    Offset: 'Offset',
    Vector: 'Vector',
    Point: 'Point',
    CovariantVector: 'CovariantVector',
    SymmetricSecondRankTensor: 'SymmetricSecondRankTensor',
    DiffusionTensor3D: 'DiffusionTensor3D',
    Complex: 'Complex',
    FixedArray: 'FixedArray',
    Array: 'Array',
    Matrix: 'Matrix',
    VariableLengthVector: 'VariableLengthVector',
    VariableSizeMatrix: 'VariableSizeMatrix'
};
var PixelTypes$1 = PixelTypes;

function setMatrixElement(matrixData, columns, row, column, value) {
    matrixData[column + row * columns] = value;
}

class ImageType {
    constructor(dimension = 2, componentType = IntTypes.UInt8, pixelType = PixelTypes$1.Scalar, components = 1) {
        this.dimension = dimension;
        this.componentType = componentType;
        this.pixelType = pixelType;
        this.components = components;
    }
}
var ImageType$1 = ImageType;

class Image {
    constructor(imageType = new ImageType$1()) {
        this.imageType = imageType;
        this.name = 'image';
        const dimension = imageType.dimension;
        this.origin = new Array(dimension);
        this.origin.fill(0.0);
        this.spacing = new Array(dimension);
        this.spacing.fill(1.0);
        this.direction = new Float64Array(dimension * dimension);
        this.direction.fill(0.0);
        for (let ii = 0; ii < dimension; ii++) {
            setMatrixElement(this.direction, dimension, ii, ii, 1.0);
        }
        this.size = new Array(dimension);
        this.size.fill(0);
        this.metadata = new Map();
        this.data = null;
    }
}
var Image$1 = Image;

function copyImage(image) {
    const copy = new Image$1(image.imageType);
    copy.name = image.name;
    copy.origin = Array.from(image.origin);
    copy.spacing = Array.from(image.spacing);
    copy.direction = image.direction.slice();
    copy.size = Array.from(image.size);
    if (image.data !== null) {
        const CTor = image.data.constructor;
        copy.data = new CTor(image.data.length);
        if (copy.data != null) {
            // @ts-expect-error: error TS2345: Argument of type 'TypedArray' is not assignable to parameter of type 'ArrayLike<number> & ArrayLike<bigint>'
            copy.data.set(image.data, 0);
        }
    }
    return copy;
}

/** Join an array of sequential image slabs into a single image */
function stackImages(images) {
    if (images.length < 1) {
        throw Error('At least one images is required.');
    }
    const firstImage = images[0];
    if (firstImage.data === null) {
        throw Error('Image data is null.');
    }
    const result = new Image$1(firstImage.imageType);
    result.origin = Array.from(firstImage.origin);
    result.spacing = Array.from(firstImage.spacing);
    const dimension = result.imageType.dimension;
    result.direction = firstImage.direction.slice();
    const stackOn = dimension - 1;
    result.size = Array.from(firstImage.size);
    const stackedSize = images.reduce((accumulator, currentValue) => {
        return accumulator + currentValue.size[stackOn];
    }, 0);
    result.size[stackOn] = stackedSize;
    const dataSize = result.size.reduce((accumulator, currentValue) => { return accumulator * currentValue; }, 1) * result.imageType.components;
    const CTor = firstImage.data.constructor;
    result.data = new CTor(dataSize);
    let offsetBase = result.imageType.components;
    for (let subIndex = 0; subIndex < result.size.length - 1; subIndex++) {
        offsetBase *= result.size[subIndex];
    }
    let stackIndex = 0;
    if (result.data != null) {
        for (let index = 0; index < images.length; index++) {
            // @ts-expect-error: error TS2345: Argument of type 'TypedArray' is not assignable to parameter of type 'ArrayLike<number> & ArrayLike<bigint>'.
            result.data.set(images[index].data, offsetBase * stackIndex);
            stackIndex += images[index].size[stackOn];
        }
    }
    else {
        throw Error('Could not create result image data.');
    }
    return result;
}

/**
 * Cast an image to another PixelType and/or ComponentType
 *
 * @param {Image} image - The input image
 * @param {CastImageOptions} options - specify the componentType and/or pixelType of the output
 */
function castImage(inputImage, options) {
    const outputImageType = Object.assign({}, inputImage.imageType);
    if (typeof options !== 'undefined' && typeof options.pixelType !== 'undefined') {
        outputImageType.pixelType = options.pixelType;
        if (options.pixelType === PixelTypes$1.Scalar && outputImageType.components !== 1) {
            throw new Error('Cannot cast multi-component image to a scalar image');
        }
    }
    if (typeof options !== 'undefined' && typeof options.componentType !== 'undefined' && options.componentType !== inputImage.imageType.componentType) {
        outputImageType.componentType = options.componentType;
    }
    const outputImage = new Image$1(outputImageType);
    outputImage.name = inputImage.name;
    outputImage.origin = Array.from(inputImage.origin);
    outputImage.spacing = Array.from(inputImage.spacing);
    outputImage.direction = inputImage.direction.slice();
    outputImage.size = Array.from(inputImage.size);
    // Deep copy the map
    outputImage.metadata = new Map(JSON.parse(JSON.stringify(Array.from(inputImage.metadata))));
    if (inputImage.data !== null) {
        if (typeof options !== 'undefined' && typeof options.componentType !== 'undefined' && options.componentType !== inputImage.imageType.componentType) {
            switch (inputImage.imageType.componentType) {
                case IntTypes.UInt8:
                case IntTypes.Int8:
                case IntTypes.UInt16:
                case IntTypes.Int16:
                case IntTypes.UInt32:
                case IntTypes.Int32:
                case FloatTypes.Float32:
                case FloatTypes.Float64:
                    switch (outputImage.imageType.componentType) {
                        case IntTypes.UInt8:
                            outputImage.data = new Uint8Array(inputImage.data);
                            break;
                        case IntTypes.Int8:
                            outputImage.data = new Int8Array(inputImage.data);
                            break;
                        case IntTypes.UInt16:
                            outputImage.data = new Uint16Array(inputImage.data);
                            break;
                        case IntTypes.Int16:
                            outputImage.data = new Int16Array(inputImage.data);
                            break;
                        case IntTypes.UInt32:
                            outputImage.data = new Uint32Array(inputImage.data);
                            break;
                        case IntTypes.Int32:
                            outputImage.data = new Int32Array(inputImage.data);
                            break;
                        case FloatTypes.Float32:
                            outputImage.data = new Float32Array(inputImage.data);
                            break;
                        case FloatTypes.Float64:
                            outputImage.data = new Float64Array(inputImage.data);
                            break;
                        case IntTypes.UInt64:
                            outputImage.data = new BigUint64Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = BigInt.asIntN(64, BigInt(inputImage.data[idx]));
                            }
                            break;
                        case IntTypes.Int64:
                            outputImage.data = new BigInt64Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = BigInt.asUintN(64, BigInt(inputImage.data[idx]));
                            }
                            break;
                    }
                    break;
                case IntTypes.UInt64:
                case IntTypes.Int64:
                    switch (outputImage.imageType.componentType) {
                        case IntTypes.UInt8:
                            outputImage.data = new Uint8Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case IntTypes.Int8:
                            outputImage.data = new Int8Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case IntTypes.UInt16:
                            outputImage.data = new Uint16Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case IntTypes.Int16:
                            outputImage.data = new Int16Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case IntTypes.UInt32:
                            outputImage.data = new Uint32Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case IntTypes.Int32:
                            outputImage.data = new Int32Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case FloatTypes.Float32:
                            outputImage.data = new Float32Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case FloatTypes.Float64:
                            outputImage.data = new Float64Array(inputImage.data.length);
                            for (let idx = 0; idx < outputImage.data.length; idx++) {
                                outputImage.data[idx] = Number(inputImage.data[idx]);
                            }
                            break;
                        case IntTypes.UInt64:
                            outputImage.data = new BigUint64Array(inputImage.data);
                            break;
                        case IntTypes.Int64:
                            outputImage.data = new BigInt64Array(inputImage.data);
                            break;
                    }
                    break;
            }
        }
        else {
            // copy
            const CTor = inputImage.data.constructor;
            outputImage.data = new CTor(inputImage.data.length);
            if (outputImage.data != null) {
                // @ts-expect-error: error TS2345: Argument of type 'TypedArray' is not assignable to parameter of type 'ArrayLike<number> & ArrayLike<bigint>'
                outputImage.data.set(inputImage.data, 0);
            }
        }
    }
    return outputImage;
}

/* eslint-disable  @typescript-eslint/no-non-null-assertion */
var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
class WorkerPool {
    /* poolSize is the maximum number of web workers to create in the pool.
     *
     * The function, fcn, should accept null or an existing worker as its first argument.
     * It most also return and object with the used worker on the `webWorker`
     * property.  * Example: runPipeline.
     *
     **/
    constructor(poolSize, fcn) {
        this.fcn = fcn;
        this.workerQueue = new Array(poolSize);
        this.workerQueue.fill(null);
        this.runInfo = [];
    }
    /*
     * Run the tasks specified by the arguments in the taskArgsArray that will
     * be passed to the pool fcn.
     *
     * An optional progressCallback will be called with the number of complete
     * tasks and the total number of tasks as arguments every time a task has
     * completed.
     *
     * Returns an object containing a promise ('promise') to communicate results
     * as well as an id ('runId') which can be used to cancel any remaining pending
     * tasks before they complete.
     */
    runTasks(taskArgsArray, progressCallback = null) {
        const info = {
            taskQueue: [],
            results: [],
            addingTasks: false,
            postponed: false,
            runningWorkers: 0,
            index: 0,
            completedTasks: 0,
            progressCallback: progressCallback,
            canceled: false
        };
        this.runInfo.push(info);
        info.index = this.runInfo.length - 1;
        return {
            promise: new Promise((resolve, reject) => {
                info.resolve = resolve;
                info.reject = reject;
                info.results = new Array(taskArgsArray.length);
                info.completedTasks = 0;
                info.addingTasks = true;
                taskArgsArray.forEach((taskArg, index) => {
                    this.addTask(info.index, index, taskArg);
                });
                info.addingTasks = false;
            }),
            runId: info.index
        };
    }
    terminateWorkers() {
        for (let index = 0; index < this.workerQueue.length; index++) {
            const worker = this.workerQueue[index];
            if (worker != null) {
                worker.terminate();
            }
            this.workerQueue[index] = null;
        }
    }
    cancel(runId) {
        const info = this.runInfo[runId];
        if (info !== null && info !== undefined) {
            info.canceled = true;
        }
    }
    addTask(infoIndex, resultIndex, taskArgs) {
        const info = this.runInfo[infoIndex];
        if ((info === null || info === void 0 ? void 0 : info.canceled) === true) {
            info.reject('Remaining tasks canceled');
            this.clearTask(info.index);
            return;
        }
        if (this.workerQueue.length > 0) {
            const worker = this.workerQueue.pop();
            info.runningWorkers++;
            this.fcn(worker, ...taskArgs).then((_a) => {
                var { webWorker } = _a, result = __rest(_a, ["webWorker"]);
                this.workerQueue.push(webWorker);
                // Check if this task was canceled while it was getting done
                if (this.runInfo[infoIndex] !== null) {
                    info.runningWorkers--;
                    info.results[resultIndex] = result;
                    info.completedTasks++;
                    if (info.progressCallback != null) {
                        info.progressCallback(info.completedTasks, info.results.length);
                    }
                    if (info.taskQueue.length > 0) {
                        const reTask = info.taskQueue.shift();
                        this.addTask(infoIndex, reTask[0], reTask[1]);
                    }
                    else if (!info.addingTasks && info.runningWorkers === 0) {
                        const results = info.results;
                        info.resolve(results);
                        this.clearTask(info.index);
                    }
                }
            }).catch((error) => {
                info.reject(error);
                this.clearTask(info.index);
            });
        }
        else {
            if (info.runningWorkers !== 0 || info.postponed) {
                // At least one worker is working on these tasks, and it will pick up
                // the next item in the taskQueue when done.
                info.taskQueue.push([resultIndex, taskArgs]);
            }
            else {
                // Try again later.
                info.postponed = true;
                setTimeout(() => {
                    info.postponed = false;
                    this.addTask(info.index, resultIndex, taskArgs);
                }, 50);
            }
        }
    }
    clearTask(clearIndex) {
        this.runInfo[clearIndex].results = [];
        this.runInfo[clearIndex].taskQueue = [];
        this.runInfo[clearIndex].progressCallback = null;
        this.runInfo[clearIndex].canceled = null;
        this.runInfo[clearIndex].reject = () => { };
        this.runInfo[clearIndex].resolve = () => { };
    }
}
var WorkerPool$1 = WorkerPool;

let TinyEmitter$1 = class TinyEmitter {
  constructor() {
    Object.defineProperty(this, '__listeners', {
      value: {},
      enumerable: false,
      writable: false
    });
  }

  emit(eventName, ...args) {
    if(!this.__listeners[eventName])
      return this;

    for(const handler of this.__listeners[eventName]) {
      handler(...args);
    }

    return this;
  }

  once(eventName, handler) {
    const once = (...args) => {
      this.off(eventName, once);
      handler(...args);
    };

    return this.on(eventName, once);
  }

  on(eventName, handler) {
    if(!this.__listeners[eventName])
      this.__listeners[eventName] = [];

    this.__listeners[eventName].push(handler);

    return this;
  }

  off(eventName, handler) {
    if(handler)
      this.__listeners[eventName] = this.__listeners[eventName].filter(h => h !== handler);
    else
      this.__listeners[eventName] = [];

    return this;
  }
};

var tinyEmitter = TinyEmitter$1;

const TinyEmitter = tinyEmitter;

const MESSAGE_RESULT = 0;
const MESSAGE_EVENT = 1;
const RESULT_SUCCESS = 1;

let Worker$1 = class Worker extends TinyEmitter {
  /**
   *
   * @param worker {Worker}
   */
  constructor(worker) {
    super();

    this._messageId = 1;
    this._messages = new Map();

    this._worker = worker;
    this._worker.onmessage = this._onMessage.bind(this);
    this._id = Math.ceil(Math.random() * 10000000);
  }

  terminate() {
    this._worker.terminate();
  }

  /**
   * return true if there is no unresolved jobs
   * @returns {boolean}
   */
  isFree() {
    return this._messages.size === 0;
  }

  jobsLength() {
    return this._messages.size;
  }

  /**
   * @param operationName string
   * @param data any
   * @param transferable array
   * @param onEvent function
   * @returns {Promise}
   */
  exec(operationName, data = null, transferable = [], onEvent) {
    return new Promise((res, rej) => {
      const messageId = this._messageId++;
      this._messages.set(messageId, [res, rej, onEvent]);
      this._worker.postMessage([messageId, data, operationName], transferable || []);
    });
  }

  /**
   *
   * @param data any
   * @param transferable array
   * @param onEvent function
   * @returns {Promise}
   */
  postMessage(data = null, transferable = [], onEvent) {
    return new Promise((res, rej) => {
      const messageId = this._messageId++;
      this._messages.set(messageId, [res, rej, onEvent]);
      this._worker.postMessage([messageId, data], transferable || []);
    });
  }

  emit(eventName, ...args) {
    this._worker.postMessage({eventName, args});
  }

  _onMessage(e) {
    //if we got usual event, just emit it locally
    if(!Array.isArray(e.data) && e.data.eventName) {
      return super.emit(e.data.eventName, ...e.data.args);
    }

    const [type, ...args] = e.data;

    if(type === MESSAGE_EVENT)
      this._onEvent(...args);
    else if(type === MESSAGE_RESULT)
      this._onResult(...args);
    else
      throw new Error(`Wrong message type '${type}'`);
  }

  _onResult(messageId, success, payload) {
    const [res, rej] = this._messages.get(messageId);
    this._messages.delete(messageId);

    return success === RESULT_SUCCESS ? res(payload) : rej(payload);
  }

  _onEvent(messageId, eventName, data) {
    const [,,onEvent] = this._messages.get(messageId);

    if(onEvent) {
      onEvent(eventName, data);
    }
  }

};

var src = Worker$1;

var WebworkerPromise = /*@__PURE__*/getDefaultExportFromCjs(src);

// Internal function to create a web worker promise
async function createWebWorkerPromise(existingWorker, pipelineWorkerUrl) {
    let workerPromise;
    if (existingWorker != null) {
        // See if we have a worker promise attached the worker, if so reuse it. This ensures
        // that we can safely reuse the worker without issues.
        const itkWebWorker = existingWorker;
        if (itkWebWorker.workerPromise !== undefined) {
            workerPromise = itkWebWorker.workerPromise;
        }
        else {
            workerPromise = new WebworkerPromise(existingWorker);
        }
        return await Promise.resolve({ webworkerPromise: workerPromise, worker: existingWorker });
    }
    const workerUrl = typeof pipelineWorkerUrl === 'undefined' ? config.pipelineWorkerUrl : pipelineWorkerUrl;
    let worker = null;
    // @ts-expect-error: error TS2339: Property 'webWorkersUrl' does not exist on type '{ pipelineWorkerUrl: string; imageIOUrl: string; meshIOUrl: string; pipelinesUrl: string; }
    const webWorkersUrl = config.webWorkersUrl;
    if (typeof webWorkersUrl !== 'undefined') {
        console.warn('itkConfig webWorkersUrl is deprecated. Please use pipelineWorkerUrl with the full path to the pipeline worker.');
        const min = 'min-';
        // debug
        // const min = ''
        const webWorkerString = webWorkersUrl;
        if (webWorkerString.startsWith('http')) {
            const response = await axios.get(`${webWorkerString}/${min}bundles/pipeline.worker.js`, { responseType: 'blob' });
            worker = new Worker(URL.createObjectURL(response.data));
        }
        else {
            worker = new Worker(`${webWorkerString}/${min}bundles/pipeline.worker.js`);
        }
    }
    else if (workerUrl === null) {
        // Use the version built with the bundler
        //
        // Bundlers, e.g. WebPack, Vite, Rollup, see these paths at build time
        worker = new Worker(new URL("pipeline.worker-466b2924.js", import.meta.url), { type: 'module' });
    }
    else {
        if (workerUrl.startsWith('http')) {
            const response = await axios.get(workerUrl, { responseType: 'blob' });
            worker = new Worker(URL.createObjectURL(response.data));
        }
        else {
            worker = new Worker(workerUrl);
        }
    }
    const webworkerPromise = new WebworkerPromise(worker);
    // Attach the worker promise to the worker, so if the worker is reused we can
    // also reuse the the worker promise.
    const itkWebWorker = worker;
    itkWebWorker.workerPromise = webworkerPromise;
    return { webworkerPromise, worker: itkWebWorker };
}

let pipelinesBaseUrl$1;
function getPipelinesBaseUrl$1() {
    return pipelinesBaseUrl$1;
}

async function loadEmscriptenModuleMainThread(moduleRelativePathOrURL, baseUrl) {
    let modulePrefix = 'unknown';
    if (typeof moduleRelativePathOrURL !== 'string') {
        modulePrefix = moduleRelativePathOrURL.href;
    }
    else if (moduleRelativePathOrURL.startsWith('http')) {
        modulePrefix = moduleRelativePathOrURL;
    }
    else {
        modulePrefix = `${baseUrl}/${moduleRelativePathOrURL}`;
    }
    if (modulePrefix.endsWith('.js')) {
        modulePrefix = modulePrefix.substring(0, modulePrefix.length - 3);
    }
    if (modulePrefix.endsWith('.wasm')) {
        modulePrefix = modulePrefix.substring(0, modulePrefix.length - 5);
    }
    const wasmBinaryPath = `${modulePrefix}.wasm`;
    const response = await axios.get(wasmBinaryPath, { responseType: 'arraybuffer' });
    const wasmBinary = response.data;
    const fullModulePath = `${modulePrefix}.js`;
    const result = await import(/* webpackIgnore: true */ /* @vite-ignore */ fullModulePath);
    const instantiated = result.default({ wasmBinary });
    return instantiated;
}

const simd=async()=>WebAssembly.validate(new Uint8Array([0,97,115,109,1,0,0,0,1,5,1,96,0,1,123,3,2,1,0,10,10,1,8,0,65,0,253,15,253,98,11]));

// To cache loaded pipeline modules
const pipelineToModule = new Map();
async function loadPipelineModule(pipelinePath) {
    let moduleRelativePathOrURL = pipelinePath;
    let pipeline = pipelinePath;
    if (typeof pipelinePath !== 'string') {
        moduleRelativePathOrURL = new URL(pipelinePath.href);
        pipeline = moduleRelativePathOrURL.href;
    }
    if (pipelineToModule.has(pipeline)) {
        return pipelineToModule.get(pipeline);
    }
    else {
        const pipelineModule = (await loadEmscriptenModuleMainThread(pipelinePath, config.pipelinesUrl));
        pipelineToModule.set(pipeline, pipelineModule);
        return pipelineModule;
    }
}
async function runPipeline(webWorker, pipelinePath, args, outputs, inputs, options) {
    var _a, _b;
    if (!await simd()) {
        const simdErrorMessage = 'WebAssembly SIMD support is required -- please update your browser.';
        alert(simdErrorMessage);
        throw new Error(simdErrorMessage);
    }
    if (webWorker === false) {
        const pipelineModule = await loadPipelineModule(pipelinePath.toString());
        const result = runPipelineEmscripten(pipelineModule, args, outputs, inputs);
        return result;
    }
    let worker = webWorker;
    const pipelineWorkerUrl = (_a = options === null || options === void 0 ? void 0 : options.pipelineWorkerUrl) !== null && _a !== void 0 ? _a : null;
    const pipelineWorkerUrlString = typeof pipelineWorkerUrl !== 'string' && typeof (pipelineWorkerUrl === null || pipelineWorkerUrl === void 0 ? void 0 : pipelineWorkerUrl.href) !== 'undefined' ? pipelineWorkerUrl.href : pipelineWorkerUrl;
    const { webworkerPromise, worker: usedWorker } = await createWebWorkerPromise(worker, pipelineWorkerUrlString);
    worker = usedWorker;
    const transferables = [];
    if (!(inputs == null) && inputs.length > 0) {
        inputs.forEach(function (input) {
            if (input.type === InterfaceTypes.BinaryStream) {
                // Binary data
                const dataArray = input.data.data;
                transferables.push(dataArray);
            }
            else if (input.type === InterfaceTypes.BinaryFile) {
                // Binary data
                const dataArray = input.data.data;
                transferables.push(dataArray);
            }
            else if (input.type === InterfaceTypes.Image) {
                // Image data
                const image = input.data;
                if (image.data === null) {
                    throw Error('image data cannot be null');
                }
                transferables.push(...imageTransferables(image));
            }
            else if (input.type === IOTypes.Binary) {
                // Binary data
                transferables.push(input.data);
            }
            else if (input.type === IOTypes.Image) {
                // Image data
                const image = input.data;
                if (image.data === null) {
                    throw Error('image data cannot be null');
                }
                transferables.push(...imageTransferables(image));
            }
            else if (input.type === IOTypes.Mesh) {
                // Mesh data
                const mesh = input.data;
                transferables.push(...meshTransferables(mesh));
            }
        });
    }
    const pipelineBaseUrl = (_b = options === null || options === void 0 ? void 0 : options.pipelineBaseUrl) !== null && _b !== void 0 ? _b : 'pipelinesUrl';
    const pipelineBaseUrlString = typeof pipelineBaseUrl !== 'string' && typeof (pipelineBaseUrl === null || pipelineBaseUrl === void 0 ? void 0 : pipelineBaseUrl.href) !== 'undefined' ? pipelineBaseUrl.href : pipelineBaseUrl;
    const result = await webworkerPromise.postMessage({
        operation: 'runPipeline',
        config: config,
        pipelinePath: pipelinePath.toString(),
        pipelineBaseUrl: pipelineBaseUrlString,
        args,
        outputs,
        inputs
    }, getTransferables(transferables));
    return {
        returnValue: result.returnValue,
        stdout: result.stdout,
        stderr: result.stderr,
        outputs: result.outputs,
        webWorker: worker
    };
}

var name = "@itk-wasm/image-io";
var version = "0.3.0";
var description = "Input and output for scientific and medical image file formats.";
var type = "module";
var module = "./dist/index.js";
var types = "./dist/src/index.d.ts";
var exports = {
	".": {
		types: "./dist/src/index.d.js",
		browser: "./dist/index.js",
		node: "./dist/index-node.js",
		"default": "./dist/index.js"
	}
};
var scripts = {
	start: "npm run copyShoelaceAssets && vite -c build/vite.config.js",
	test: "npm run test:node && npm run test:browser",
	"test:node": "ava",
	"test:browser": "npm run test:browser:chrome && npm run test:browser:firefox",
	"test:browser:firefox": "start-server-and-test rollup:start http-get://localhost:5004 cypress:runFirefox",
	"test:browser:chrome": "start-server-and-test rollup:start http-get://localhost:5004 cypress:runChrome",
	"test:browser:debug": "start-server-and-test rollup:start http-get://localhost:5004 cypress:open",
	"cypress:open": "npx cypress open",
	"cypress:runChrome": "npx cypress run --browser chrome",
	"cypress:runFirefox": "npx cypress run --browser firefox",
	build: "npm run build:tsc && npm run build:node && npm run build:browser && npm run build:demo",
	"build:node": "rollup -c ./build/rollup.node.config.js",
	"build:browser": "rollup -c ./build/rollup.browser.config.js",
	"build:tsc": "tsc --pretty",
	copyShoelaceAssets: "shx mkdir -p test/browser/demo-app/public && shx cp -r node_modules/@shoelace-style/shoelace/dist/assets test/browser/demo-app/public/",
	"build:demo": "npm run copyShoelaceAssets && vite -c build/vite.config.js build",
	"rollup:start": "npm run copyShoelaceAssets && concurrently npm:rollup:dev npm:rollup:preview",
	"rollup:dev": "vite build --config build/vite-rollup-watch.config.ts",
	"rollup:preview": "vite preview --config build/vite-rollup-watch.config.ts"
};
var keywords = [
	"itk",
	"wasm",
	"webassembly",
	"wasi"
];
var author = "";
var license = "Apache-2.0";
var dependencies = {
	"itk-wasm": "^1.0.0-b.149"
};
var devDependencies = {
	"@rollup/plugin-commonjs": "^24.0.0",
	"@rollup/plugin-json": "^6.0.0",
	"@rollup/plugin-node-resolve": "^15.1.0",
	"@rollup/plugin-terser": "^0.4.0",
	"@rollup/plugin-typescript": "^11.1.1",
	"@shoelace-style/shoelace": "^2.5.2",
	"@surma/rollup-plugin-off-main-thread": "^2.2.3",
	"@types/node": "^20.2.5",
	ava: "^5.3.1",
	concurrently: "^8.2.1",
	cypress: "^13.3.0",
	debug: "^4.3.4",
	rollup: "^3.9.0",
	"rollup-plugin-copy": "^3.4.0",
	"rollup-plugin-ignore": "^1.0.10",
	"rollup-plugin-polyfill-node": "^0.12.0",
	shx: "^0.3.4",
	"supports-color": "^9.3.1",
	tslib: "^2.5.2",
	typescript: "^5.0.4",
	vite: "^4.4.11",
	"vite-plugin-static-copy": "^0.17.0"
};
var repository = {
	type: "git",
	url: "https://github.com/InsightSoftwareConsortium/itk-wasm"
};
var ava = {
	files: [
		"test/node/**/*",
		"!test/node/common.js"
	]
};
var packageJson = {
	name: name,
	version: version,
	description: description,
	type: type,
	module: module,
	types: types,
	exports: exports,
	scripts: scripts,
	keywords: keywords,
	author: author,
	license: license,
	dependencies: dependencies,
	devDependencies: devDependencies,
	repository: repository,
	ava: ava
};

let pipelinesBaseUrl;
let defaultPipelinesBaseUrl = `https://cdn.jsdelivr.net/npm/@itk-wasm/image-io@${packageJson.version}/dist/pipelines`;
function setPipelinesBaseUrl(baseUrl) {
    pipelinesBaseUrl = baseUrl;
}
function getPipelinesBaseUrl() {
    if (typeof pipelinesBaseUrl !== 'undefined') {
        return pipelinesBaseUrl;
    }
    const itkWasmPipelinesBaseUrl = getPipelinesBaseUrl$1();
    if (typeof itkWasmPipelinesBaseUrl !== 'undefined') {
        return itkWasmPipelinesBaseUrl;
    }
    return defaultPipelinesBaseUrl;
}

const mimeToImageIo = new Map([
    ['image/jpeg', 'jpeg'],
    ['image/png', 'png'],
    ['image/tiff', 'tiff'],
    ['image/x-ms-bmp', 'bmp'],
    ['image/x-bmp', 'bmp'],
    ['image/bmp', 'bmp'],
    ['application/dicom', 'gdcm']
]);

const extensionToImageIo = new Map([
    ['bmp', 'bmp'],
    ['dcm', 'gdcm'],
    ['gipl', 'gipl'],
    ['gipl.gz', 'gipl'],
    ['hdf5', 'hdf5'],
    ['jpg', 'jpeg'],
    ['jpeg', 'jpeg'],
    ['iwi', 'wasm'],
    ['iwi.cbor', 'wasm'],
    ['iwi.cbor.zst', 'wasmZstd'],
    ['lsm', 'lsm'],
    ['mnc', 'mnc'],
    ['mnc.gz', 'mnc'],
    ['mnc2', 'mnc'],
    ['mgh', 'mgh'],
    ['mgz', 'mgh'],
    ['mgh.gz', 'mgh'],
    ['mha', 'meta'],
    ['mhd', 'meta'],
    ['mrc', 'mrc'],
    ['nia', 'nifti'],
    ['nii', 'nifti'],
    ['nii.gz', 'nifti'],
    ['hdr', 'nifti'],
    ['nrrd', 'nrrd'],
    ['nhdr', 'nrrd'],
    ['png', 'png'],
    ['pic', 'bioRad'],
    ['tif', 'tiff'],
    ['tiff', 'tiff'],
    ['vtk', 'vtk'],
    ['isq', 'scanco'],
    ['fdf', 'fdf'],
]);

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {PngReadImageOptions} options - options object
 *
 * @returns {Promise<PngReadImageResult>} - result object
 */
async function pngReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'png-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {PngWriteImageOptions} options - options object
 *
 * @returns {Promise<PngWriteImageResult>} - result object
 */
async function pngWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'png-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {MetaReadImageOptions} options - options object
 *
 * @returns {Promise<MetaReadImageResult>} - result object
 */
async function metaReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'meta-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {MetaWriteImageOptions} options - options object
 *
 * @returns {Promise<MetaWriteImageResult>} - result object
 */
async function metaWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'meta-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {TiffReadImageOptions} options - options object
 *
 * @returns {Promise<TiffReadImageResult>} - result object
 */
async function tiffReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'tiff-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {TiffWriteImageOptions} options - options object
 *
 * @returns {Promise<TiffWriteImageResult>} - result object
 */
async function tiffWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'tiff-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {NiftiReadImageOptions} options - options object
 *
 * @returns {Promise<NiftiReadImageResult>} - result object
 */
async function niftiReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'nifti-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {NiftiWriteImageOptions} options - options object
 *
 * @returns {Promise<NiftiWriteImageResult>} - result object
 */
async function niftiWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'nifti-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {JpegReadImageOptions} options - options object
 *
 * @returns {Promise<JpegReadImageResult>} - result object
 */
async function jpegReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'jpeg-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {JpegWriteImageOptions} options - options object
 *
 * @returns {Promise<JpegWriteImageResult>} - result object
 */
async function jpegWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'jpeg-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {NrrdReadImageOptions} options - options object
 *
 * @returns {Promise<NrrdReadImageResult>} - result object
 */
async function nrrdReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'nrrd-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {NrrdWriteImageOptions} options - options object
 *
 * @returns {Promise<NrrdWriteImageResult>} - result object
 */
async function nrrdWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'nrrd-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {VtkReadImageOptions} options - options object
 *
 * @returns {Promise<VtkReadImageResult>} - result object
 */
async function vtkReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'vtk-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {VtkWriteImageOptions} options - options object
 *
 * @returns {Promise<VtkWriteImageResult>} - result object
 */
async function vtkWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'vtk-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {BmpReadImageOptions} options - options object
 *
 * @returns {Promise<BmpReadImageResult>} - result object
 */
async function bmpReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'bmp-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {BmpWriteImageOptions} options - options object
 *
 * @returns {Promise<BmpWriteImageResult>} - result object
 */
async function bmpWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'bmp-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {Hdf5ReadImageOptions} options - options object
 *
 * @returns {Promise<Hdf5ReadImageResult>} - result object
 */
async function hdf5ReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'hdf5-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {Hdf5WriteImageOptions} options - options object
 *
 * @returns {Promise<Hdf5WriteImageResult>} - result object
 */
async function hdf5WriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'hdf5-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {MincReadImageOptions} options - options object
 *
 * @returns {Promise<MincReadImageResult>} - result object
 */
async function mincReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'minc-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {MincWriteImageOptions} options - options object
 *
 * @returns {Promise<MincWriteImageResult>} - result object
 */
async function mincWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'minc-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {MrcReadImageOptions} options - options object
 *
 * @returns {Promise<MrcReadImageResult>} - result object
 */
async function mrcReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'mrc-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {MrcWriteImageOptions} options - options object
 *
 * @returns {Promise<MrcWriteImageResult>} - result object
 */
async function mrcWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'mrc-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {LsmReadImageOptions} options - options object
 *
 * @returns {Promise<LsmReadImageResult>} - result object
 */
async function lsmReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'lsm-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {LsmWriteImageOptions} options - options object
 *
 * @returns {Promise<LsmWriteImageResult>} - result object
 */
async function lsmWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'lsm-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {MghReadImageOptions} options - options object
 *
 * @returns {Promise<MghReadImageResult>} - result object
 */
async function mghReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'mgh-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {MghWriteImageOptions} options - options object
 *
 * @returns {Promise<MghWriteImageResult>} - result object
 */
async function mghWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'mgh-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {BioRadReadImageOptions} options - options object
 *
 * @returns {Promise<BioRadReadImageResult>} - result object
 */
async function bioRadReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'bio-rad-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {BioRadWriteImageOptions} options - options object
 *
 * @returns {Promise<BioRadWriteImageResult>} - result object
 */
async function bioRadWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'bio-rad-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {GiplReadImageOptions} options - options object
 *
 * @returns {Promise<GiplReadImageResult>} - result object
 */
async function giplReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'gipl-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {GiplWriteImageOptions} options - options object
 *
 * @returns {Promise<GiplWriteImageResult>} - result object
 */
async function giplWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'gipl-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {GeAdwReadImageOptions} options - options object
 *
 * @returns {Promise<GeAdwReadImageResult>} - result object
 */
async function geAdwReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'ge-adw-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {GeAdwWriteImageOptions} options - options object
 *
 * @returns {Promise<GeAdwWriteImageResult>} - result object
 */
async function geAdwWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'ge-adw-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {Ge4ReadImageOptions} options - options object
 *
 * @returns {Promise<Ge4ReadImageResult>} - result object
 */
async function ge4ReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'ge4-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {Ge4WriteImageOptions} options - options object
 *
 * @returns {Promise<Ge4WriteImageResult>} - result object
 */
async function ge4WriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'ge4-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {Ge5ReadImageOptions} options - options object
 *
 * @returns {Promise<Ge5ReadImageResult>} - result object
 */
async function ge5ReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'ge5-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {Ge5WriteImageOptions} options - options object
 *
 * @returns {Promise<Ge5WriteImageResult>} - result object
 */
async function ge5WriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'ge5-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {GdcmReadImageOptions} options - options object
 *
 * @returns {Promise<GdcmReadImageResult>} - result object
 */
async function gdcmReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'gdcm-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {GdcmWriteImageOptions} options - options object
 *
 * @returns {Promise<GdcmWriteImageResult>} - result object
 */
async function gdcmWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'gdcm-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {ScancoReadImageOptions} options - options object
 *
 * @returns {Promise<ScancoReadImageResult>} - result object
 */
async function scancoReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'scanco-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {ScancoWriteImageOptions} options - options object
 *
 * @returns {Promise<ScancoWriteImageResult>} - result object
 */
async function scancoWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'scanco-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {FdfReadImageOptions} options - options object
 *
 * @returns {Promise<FdfReadImageResult>} - result object
 */
async function fdfReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'fdf-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {WasmReadImageOptions} options - options object
 *
 * @returns {Promise<WasmReadImageResult>} - result object
 */
async function wasmReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'wasm-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {WasmWriteImageOptions} options - options object
 *
 * @returns {Promise<WasmWriteImageResult>} - result object
 */
async function wasmWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'wasm-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {WasmZstdReadImageOptions} options - options object
 *
 * @returns {Promise<WasmZstdReadImageResult>} - result object
 */
async function wasmZstdReadImage(webWorker, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.Image },
    ];
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof File) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    const inputs = [
        { type: InterfaceTypes.BinaryFile, data: serializedImageFile },
    ];
    const args = [];
    // Inputs
    const serializedImageName = serializedImageFile.path;
    args.push(serializedImageName);
    // Outputs
    const couldReadName = '0';
    args.push(couldReadName);
    const imageName = '1';
    args.push(imageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    const pipelinePath = 'wasm-zstd-read-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldRead: outputs[0]?.data,
        image: outputs[1]?.data,
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {WasmZstdWriteImageOptions} options - options object
 *
 * @returns {Promise<WasmZstdWriteImageResult>} - result object
 */
async function wasmZstdWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'wasm-zstd-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

const imageIoIndex = new Map([
    ['png', [pngReadImage, pngWriteImage]],
    ['meta', [metaReadImage, metaWriteImage]],
    ['tiff', [tiffReadImage, tiffWriteImage]],
    ['nifti', [niftiReadImage, niftiWriteImage]],
    ['jpeg', [jpegReadImage, jpegWriteImage]],
    ['nrrd', [nrrdReadImage, nrrdWriteImage]],
    ['vtk', [vtkReadImage, vtkWriteImage]],
    ['bmp', [bmpReadImage, bmpWriteImage]],
    ['hdf5', [hdf5ReadImage, hdf5WriteImage]],
    ['minc', [mincReadImage, mincWriteImage]],
    ['mrc', [mrcReadImage, mrcWriteImage]],
    ['lsm', [lsmReadImage, lsmWriteImage]],
    ['mgh', [mghReadImage, mghWriteImage]],
    ['bioRad', [bioRadReadImage, bioRadWriteImage]],
    ['gipl', [giplReadImage, giplWriteImage]],
    ['geAdw', [geAdwReadImage, geAdwWriteImage]],
    ['ge4', [ge4ReadImage, ge4WriteImage]],
    ['ge5', [ge5ReadImage, ge5WriteImage]],
    ['gdcm', [gdcmReadImage, gdcmWriteImage]],
    ['scanco', [scancoReadImage, scancoWriteImage]],
    ['fdf', [fdfReadImage, null]],
    ['wasm', [wasmReadImage, wasmWriteImage]],
    ['wasmZstd', [wasmZstdReadImage, wasmZstdWriteImage]]
]);

/**
 * Read an image file format and convert it to the itk-wasm file format
 *
 * @param {webWorker} null | webWorker - Web worker to run the pipeline or null to run it in a new worker
 * @param {File | BinaryFile} serializedImage - Input image serialized in the file format
 * @param {ReadImageOptions} options - options to cast the resulting image type or to only read image metadata
 *
 * @returns {Promise<ReadImageResult>} - result object with the image and the web worker used
 */
async function readImage(webWorker, serializedImage, options = {}) {
    const mimeType = serializedImage.type ?? '';
    const fileName = serializedImage.name ?? serializedImage.path ?? 'fileName';
    const extension = getFileExtension(fileName).toLowerCase();
    let usedWebWorker = webWorker;
    let serializedImageFile = serializedImage;
    if (serializedImage instanceof Blob) {
        const serializedImageBuffer = await serializedImage.arrayBuffer();
        serializedImageFile = { path: serializedImage.name, data: new Uint8Array(serializedImageBuffer) };
    }
    let io = null;
    if (mimeType && mimeToImageIo.has(mimeType)) {
        io = mimeToImageIo.get(mimeType);
    }
    else if (extensionToImageIo.has(extension)) {
        io = extensionToImageIo.get(extension);
    }
    else {
        for (const readerWriter of imageIoIndex.values()) {
            if (readerWriter[0] !== null) {
                let { webWorker: testWebWorker, couldRead, image } = await readerWriter[0](usedWebWorker, { path: serializedImageFile.path, data: serializedImageFile.data.slice() }, { informationOnly: options.informationOnly });
                usedWebWorker = testWebWorker;
                if (couldRead) {
                    if (typeof options !== 'undefined') {
                        image = castImage(image, options);
                    }
                    return { webWorker: usedWebWorker, image };
                }
            }
        }
    }
    if (!io) {
        throw Error('Could not find IO for: ' + fileName);
    }
    const readerWriter = imageIoIndex.get(io);
    const reader = readerWriter[0];
    let { webWorker: testWebWorker, couldRead, image } = await reader(usedWebWorker, serializedImageFile, { informationOnly: options.informationOnly });
    usedWebWorker = testWebWorker;
    if (!couldRead) {
        throw Error('Could not read: ' + fileName);
    }
    if (typeof options !== 'undefined') {
        image = castImage(image, options);
    }
    return { webWorker: usedWebWorker, image };
}

const numberOfWorkers = typeof globalThis.navigator?.hardwareConcurrency === 'number' ? globalThis.navigator.hardwareConcurrency : 6;
const workerPool = new WorkerPool$1(numberOfWorkers, readImage);
async function readImageFileSeries(fileList, options) {
    let zSpacing = 1.0;
    let zOrigin = 0.0;
    let sortedSeries = false;
    if (typeof options === 'object') {
        if (typeof options.zSpacing !== 'undefined') {
            zSpacing = options.zSpacing;
        }
        if (typeof options.zOrigin !== 'undefined') {
            zOrigin = options.zOrigin;
        }
        if (typeof options.sortedSeries !== 'undefined') {
            sortedSeries = options.sortedSeries;
        }
    }
    const fetchFileDescriptions = Array.from(fileList, async function (file) {
        return await file.arrayBuffer().then(function (arrayBuffer) {
            const fileDescription = {
                name: file.name,
                type: file.type,
                data: arrayBuffer
            };
            return fileDescription;
        });
    });
    const fileDescriptions = await Promise.all(fetchFileDescriptions);
    if (!sortedSeries) {
        fileDescriptions.sort((a, b) => {
            if (a.name < b.name) {
                return -1;
            }
            if (a.name > b.name) {
                return 1;
            }
            return 0;
        });
    }
    const taskArgsArray = [];
    for (let index = 0; index < fileDescriptions.length; index++) {
        taskArgsArray.push([fileDescriptions[index].data, fileDescriptions[index].name]);
    }
    const results = await workerPool.runTasks(taskArgsArray).promise;
    const images = results.map((result) => {
        const image = result.image;
        image.imageType.dimension = 3;
        image.size.push(1);
        image.spacing.push(zSpacing);
        image.origin.push(zOrigin);
        image.direction = new Float64Array(9);
        image.direction.fill(0.0);
        image.direction[0] = 1.0;
        image.direction[4] = 1.0;
        image.direction[8] = 1.0;
        return image;
    });
    let stacked = stackImages(images);
    if (typeof options === 'object' && (typeof options.componentType !== 'undefined' || typeof options.pixelType !== 'undefined')) {
        stacked = castImage(stacked, options);
    }
    return { image: stacked, webWorkerPool: workerPool };
}

/**
 * Write an itk-wasm Image converted to an serialized image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {WriteImageOptions} options - options object
 *
 * @returns {Promise<WriteImageResult>} - result object
 */
async function writeImage(webWorker, image, serializedImage, options = {}) {
    let inputImage = image;
    if (typeof options.componentType !== 'undefined' || typeof options.pixelType !== 'undefined') {
        inputImage = castImage(image, options);
    }
    const mimeType = options.mimeType;
    const extension = getFileExtension(serializedImage).toLowerCase();
    let usedWebWorker = webWorker;
    let io = null;
    if (typeof mimeType !== 'undefined' && mimeToImageIo.has(mimeType)) {
        io = mimeToImageIo.get(mimeType);
    }
    else if (extensionToImageIo.has(extension)) {
        io = extensionToImageIo.get(extension);
    }
    else {
        for (const readerWriter of imageIoIndex.values()) {
            if (readerWriter[1] !== null) {
                let { webWorker: testWebWorker, couldWrite, serializedImage: serializedImageBuffer } = await readerWriter[1](usedWebWorker, copyImage(inputImage), serializedImage, options);
                usedWebWorker = testWebWorker;
                if (couldWrite) {
                    return { webWorker: usedWebWorker, serializedImage: serializedImageBuffer };
                }
            }
        }
    }
    if (!io) {
        throw Error('Could not find IO for: ' + serializedImage);
    }
    const readerWriter = imageIoIndex.get(io);
    const writer = readerWriter[1];
    let { webWorker: testWebWorker, couldWrite, serializedImage: serializedImageBuffer } = await writer(usedWebWorker, inputImage, serializedImage, options);
    usedWebWorker = testWebWorker;
    if (!couldWrite) {
        throw Error('Could not write: ' + serializedImage);
    }
    const result = {
        webWorker: usedWebWorker,
        serializedImage: serializedImageBuffer
    };
    return result;
}

// Generated file. To retain edits, remove this comment.
/**
 * Write an itk-wasm file format converted to an image file format
 *
 * @param {Image} image - Input image
 * @param {string} serializedImage - Output image serialized in the file format.
 * @param {FdfWriteImageOptions} options - options object
 *
 * @returns {Promise<FdfWriteImageResult>} - result object
 */
async function fdfWriteImage(webWorker, image, serializedImage, options = {}) {
    const desiredOutputs = [
        { type: InterfaceTypes.JsonCompatible },
        { type: InterfaceTypes.BinaryFile, data: { path: serializedImage, data: new Uint8Array() } },
    ];
    const inputs = [
        { type: InterfaceTypes.Image, data: image },
    ];
    const args = [];
    // Inputs
    const imageName = '0';
    args.push(imageName);
    // Outputs
    const couldWriteName = '0';
    args.push(couldWriteName);
    const serializedImageName = serializedImage;
    args.push(serializedImageName);
    // Options
    args.push('--memory-io');
    if (typeof options.informationOnly !== "undefined") {
        options.informationOnly && args.push('--information-only');
    }
    if (typeof options.useCompression !== "undefined") {
        options.useCompression && args.push('--use-compression');
    }
    const pipelinePath = 'fdf-write-image';
    const { webWorker: usedWebWorker, returnValue, stderr, outputs } = await runPipeline(webWorker, pipelinePath, args, desiredOutputs, inputs, { pipelineBaseUrl: getPipelinesBaseUrl() });
    if (returnValue !== 0 && stderr !== "") {
        throw new Error(stderr);
    }
    const result = {
        webWorker: usedWebWorker,
        couldWrite: outputs[0]?.data,
        serializedImage: outputs[1]?.data,
    };
    return result;
}

export { bioRadReadImage, bioRadWriteImage, bmpReadImage, bmpWriteImage, fdfReadImage, fdfWriteImage, gdcmReadImage, gdcmWriteImage, ge4ReadImage, ge4WriteImage, ge5ReadImage, ge5WriteImage, geAdwReadImage, geAdwWriteImage, getPipelinesBaseUrl, giplReadImage, giplWriteImage, hdf5ReadImage, hdf5WriteImage, jpegReadImage, jpegWriteImage, lsmReadImage, lsmWriteImage, metaReadImage, metaWriteImage, mghReadImage, mghWriteImage, mincReadImage, mincWriteImage, mrcReadImage, mrcWriteImage, niftiReadImage, niftiWriteImage, nrrdReadImage, nrrdWriteImage, pngReadImage, pngWriteImage, readImage, readImageFileSeries, scancoReadImage, scancoWriteImage, setPipelinesBaseUrl, tiffReadImage, tiffWriteImage, vtkReadImage, vtkWriteImage, wasmReadImage, wasmWriteImage, wasmZstdReadImage, wasmZstdWriteImage, writeImage };
//# sourceMappingURL=index.js.map
